package com.holub.tools;
import java.io.*;
import com.holub.asynch.JDK_11_unloading_bug_fix;

/** A convenience class that takes care of wrapping a writer around
 *  standard output.
 */

public final class Std
{
 	static{ new JDK_11_unloading_bug_fix(Std.class); }	//#bug_fix

	private static BufferedReader input;		//= null
	private static PrintWriter 	  output; 		//= null
	private static PrintWriter 	  error;  		//= null
	private static PrintWriter 	  bit_bucket;	//= null

	/*******************************************************************
	 * A private constructor, prevents anyone from manufacturing an
	 * instance.
	 */
	private Std(){}

	/*******************************************************************
	 * Get a BufferedReader that wraps System.in
	 */
	public static BufferedReader in()
	{
		if( input == null )
			synchronized( Std.class )
			{	if( input == null )
					try
					{	input =	new BufferedReader(
										new InputStreamReader(System.in));
					}
					catch( Exception e )
					{	throw new Error( e.getMessage() );
					}
			}
		return input;
	}

	/*******************************************************************
	 * Get a PrintWriter that wraps System.out.
	 */
	public static PrintWriter out()
	{	if( output == null )
			synchronized( Std.class )
			{	if( output == null )
					output = new PrintWriter( System.out, true );
			}
		return output;
	}

	/*******************************************************************
	 * Get a PrintWriter that wraps System.err.
	 */

	public static PrintWriter err()
	{	if( error == null )
			synchronized( Std.class )
			{	if( error == null )
					error = new PrintWriter( System.err, true );
			}
		return error;
	}

	/*******************************************************************
	 * Get an output stream that just discards the characters that are
	 * sent to it.
	 */

	public static PrintWriter bit_bucket()
	{	if( bit_bucket == null )
			synchronized( Std.class )
			{	if( bit_bucket == null )
					bit_bucket = new Bit_bucket();
			}
		return bit_bucket;
	}
	/**
	 * The Bit_bucket class overrides all methods of PrintWriter to
	 * do nothing.
	 */
	private static final class Bit_bucket extends PrintWriter
	{
		private Bit_bucket()
		{	super( System.err );	// have to pass it something legal. Is never used.
		}

		public void	   close()	   							{}
		public void	   flush()	   							{}
		public void	   print(boolean b)						{}
		public void	   print(char c)						{}
		public void	   print(char[] s)						{}
		public void	   print(double d)						{}
		public void	   print(float f)						{}
		public void	   print(int i)							{}
		public void	   print(long l)						{}
		public void	   print(Object o)						{}
		public void	   print(String  s)						{}
		public void	   println()							{}
		public void	   println(boolean b)					{}
		public void	   println(char c)						{}
		public void	   println(char[] s)					{}
		public void	   println(double d)					{}
		public void	   println(float f)						{}
		public void	   println(int i)						{}
		public void	   println(long l)						{}
		public void	   println(Object o)					{}
		public void	   write(char[] buf)					{}
		public void	   write(char[] buf, int off, int len)	{}
		public void	   write(int c)							{}
		public void	   write(String buf)					{}
		public void	   write(String buf, int off, int len)	{}
	}

	static public class Test
	{
		static public void main( String[] args ) throws IOException
		{	String s;
			while( (s = Std.in().readLine()) != null )
			{	Std.out().println( s );
				Std.err().println( s );
				Std.bit_bucket().println( s );
			}
		}
	}
}
